==> v-sim_3.4.0.3.orig.tar.gz: v_sim-3.4.0.3/src/openGLFunctions/objectList.h <==
/*   EXTRAITS DE LA LICENCE
	Copyright CEA, contributeurs : Luc BILLARD et Damien
	CALISTE, laboratoire L_Sim, (2001-2005)
  
	Adresse ml :
	BILLARD, non joignable par ml ;
	CALISTE, damien P caliste AT cea P fr.

	Ce logiciel est un programme informatique servant  visualiser des
	structures atomiques dans un rendu pseudo-3D. 

	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
	respectant les principes de diffusion des logiciels libres. Vous pouvez
	utiliser, modifier et/ou redistribuer ce programme sous les conditions
	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
	sur le site "http://www.cecill.info".

	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
	pris connaissance de la licence CeCILL, et que vous en avez accept les
	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
*/

/*   LICENCE SUM UP
	Copyright CEA, contributors : Luc BILLARD et Damien
	CALISTE, laboratoire L_Sim, (2001-2005)

	E-mail address:
	BILLARD, not reachable any more ;
	CALISTE, damien P caliste AT cea P fr.

	This software is a computer program whose purpose is to visualize atomic
	configurations in 3D.

	This software is governed by the CeCILL  license under French law and
	abiding by the rules of distribution of free software.  You can  use, 
	modify and/ or redistribute the software under the terms of the CeCILL
	license as circulated by CEA, CNRS and INRIA at the following URL
	"http://www.cecill.info". 

	The fact that you are presently reading this means that you have had
	knowledge of the CeCILL license and that you accept its terms. You can
	find a copy of this licence shipped with this software at Documentation/licence.en.txt.
*/
#ifndef OBJECTLIST_H
#define OBJECTLIST_H

/**
 * openGLObjectList_new:
 * @size: the requested size.
 *
 * It returns the id that can be used to link glObjectList.
 * This number is also added to the list of glObjectList to be displayed.
 * The size parameter is the number of lists that could be used by
 * the user for this glObjectList. Then the next call to this function
 * will return the last value plus the size plus one.
 *
 * Returns: an identifier used by OpenGl as a list.
 */
int openGLObjectList_new(int size);

/**
 * openGLObjectList_init:
 *
 * Used to initialise this part of code, don't use it.
 */
void openGLObjectList_init();


#endif

==> v-sim_3.5.1.orig.tar.gz: v_sim-3.5.1/src/openGLFunctions/objectList.h <==
/*   EXTRAITS DE LA LICENCE
	Copyright CEA, contributeurs : Luc BILLARD et Damien
	CALISTE, laboratoire L_Sim, (2001-2005)
  
	Adresse ml :
	BILLARD, non joignable par ml ;
	CALISTE, damien P caliste AT cea P fr.

	Ce logiciel est un programme informatique servant  visualiser des
	structures atomiques dans un rendu pseudo-3D. 

	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
	respectant les principes de diffusion des logiciels libres. Vous pouvez
	utiliser, modifier et/ou redistribuer ce programme sous les conditions
	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
	sur le site "http://www.cecill.info".

	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
	pris connaissance de la licence CeCILL, et que vous en avez accept les
	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
*/

/*   LICENCE SUM UP
	Copyright CEA, contributors : Luc BILLARD et Damien
	CALISTE, laboratoire L_Sim, (2001-2005)

	E-mail address:
	BILLARD, not reachable any more ;
	CALISTE, damien P caliste AT cea P fr.

	This software is a computer program whose purpose is to visualize atomic
	configurations in 3D.

	This software is governed by the CeCILL  license under French law and
	abiding by the rules of distribution of free software.  You can  use, 
	modify and/ or redistribute the software under the terms of the CeCILL
	license as circulated by CEA, CNRS and INRIA at the following URL
	"http://www.cecill.info". 

	The fact that you are presently reading this means that you have had
	knowledge of the CeCILL license and that you accept its terms. You can
	find a copy of this licence shipped with this software at Documentation/licence.en.txt.
*/
#ifndef OBJECTLIST_H
#define OBJECTLIST_H

#include <glib.h>
#include <GL/glu.h>

/**
 * openGLObjectList_new:
 * @size: the requested size.
 *
 * It returns the id that can be used to link glObjectList.
 * This number is also added to the list of glObjectList to be displayed.
 * The size parameter is the number of lists that could be used by
 * the user for this glObjectList. Then the next call to this function
 * will return the last value plus the size plus one.
 *
 * Returns: an identifier used by OpenGl as a list.
 */
int openGLObjectList_new(int size);

/**
 * openGLObjectList_init:
 *
 * Used to initialise this part of code, don't use it.
 */
void openGLObjectList_init();

void openGLObjectListDraw_smoothArrow(GLUquadricObj *obj, int material_id,
				      gboolean tailCentered,
				      float tailLength, float tailRadius, float tailN,
				      gboolean tailUseMat, float hatLength,
				      float hatRadius, float hatN, gboolean hatUseMat);
void openGLObjectListDraw_edgeArrow(int material_id, gboolean tailCentered,
				    float tailLength, float tailRadius,
				    gboolean tailUseMat, float hatLength,
				    float hatRadius, gboolean hatUseMat);
void openGLObjectListDraw_ellipsoid(GLUquadricObj *obj, int material_id,
				    float aAxis, float bAxis,
				    float n, gboolean useMat);
void openGLObjectListDraw_torus(GLUquadricObj *obj, int material_id, float radius,
				float ratio, int nA, int nB, gboolean useMat);

#endif
